@@ -8,8 +8,15 @@
 
 #include <functional>
 
+#include <kauth_version.h>
+#if KAUTH_VERSION >= QT_VERSION_CHECK(5, 92, 0)
+#include <KAuth/Action>
+#include <KAuth/ExecuteJob>
+#else
 #include <KAuth/KAuthAction>
 #include <KAuth/KAuthExecuteJob>
+#endif
+
 #include <KLocalizedString>
 
 #include "processcore_debug.h"
