@@ -24,7 +24,11 @@
 #include <kuser.h>
 
 #if HAVE_X11
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+#include <private/qtx11extras_p.h>
+#else
 #include <QX11Info>
+#endif
 #include <X11/Xatom.h>
 #include <X11/Xlib.h>
 #include <fixx11h.h>
